@@ -34,6 +34,6 @@ def fake_save_user(user_in: UserIn):
 
 
 @app.post("/user/", response_model=UserOut)
-async def create_user(*, user_in: UserIn):
+async def create_user(user_in: UserIn):
     user_saved = fake_save_user(user_in)
     return user_saved
