@@ -15,7 +15,7 @@ class Item(BaseModel):
 
 
 @app.post("/items/", response_model=Item, tags=["items"])
-async def create_item(*, item: Item):
+async def create_item(item: Item):
     return item
 
 
