@@ -20,5 +20,5 @@ class Item(BaseModel):
     summary="Create an item",
     description="Create an item with all the information, name, description, price, tax and a set of unique tags",
 )
-async def create_item(*, item: Item):
+async def create_item(item: Item):
     return item
