@@ -15,7 +15,7 @@ class Item(BaseModel):
 
 
 @app.post("/items/", response_model=Item, summary="Create an item")
-async def create_item(*, item: Item):
+async def create_item(item: Item):
     """
     Create an item with all the information:
 
