@@ -12,6 +12,6 @@ class Item(BaseModel):
 
 
 @app.put("/items/{item_id}")
-async def update_item(*, item_id: int, item: Item):
+async def update_item(item_id: int, item: Item):
     results = {"item_id": item_id, "item": item}
     return results
