@@ -8,6 +8,7 @@ from fastapi.exception_handlers import (
     request_validation_exception_handler,
 )
 from fastapi.exceptions import RequestValidationError
+from fastapi.logger import logger
 from fastapi.openapi.docs import (
     get_redoc_html,
     get_swagger_ui_html,
@@ -36,7 +37,6 @@ class FastAPI(Starlette):
         description: str = "",
         version: str = "0.1.0",
         openapi_url: Optional[str] = "/openapi.json",
-        openapi_prefix: str = "",
         default_response_class: Type[Response] = JSONResponse,
         docs_url: Optional[str] = "/docs",
         redoc_url: Optional[str] = "/redoc",
@@ -46,6 +46,8 @@ class FastAPI(Starlette):
         exception_handlers: Dict[Union[int, Type[Exception]], Callable] = None,
         on_startup: Sequence[Callable] = None,
         on_shutdown: Sequence[Callable] = None,
+        openapi_prefix: str = "",
+        root_path: str = "",
         **extra: Dict[str, Any],
     ) -> None:
         self.default_response_class = default_response_class
@@ -68,7 +70,15 @@ class FastAPI(Starlette):
         self.description = description
         self.version = version
         self.openapi_url = openapi_url
-        self.openapi_prefix = openapi_prefix.rstrip("/")
+        # TODO: remove when discarding the openapi_prefix parameter
+        if openapi_prefix:
+            logger.warning(
+                '"openapi_prefix" has been deprecated in favor of "root_path", which '
+                "follows more closely the ASGI standard, is simpler, and more "
+                "automatic. Check the docs at "
+                "https://fastapi.tiangolo.com/advanced/sub-applications-proxy/"
+            )
+        self.root_path = root_path or openapi_prefix
         self.docs_url = docs_url
         self.redoc_url = redoc_url
         self.swagger_ui_oauth2_redirect_url = swagger_ui_oauth2_redirect_url
@@ -81,13 +91,10 @@ class FastAPI(Starlette):
         if self.openapi_url:
             assert self.title, "A title must be provided for OpenAPI, e.g.: 'My API'"
             assert self.version, "A version must be provided for OpenAPI, e.g.: '2.1.0'"
-
-        if self.docs_url or self.redoc_url:
-            assert self.openapi_url, "The openapi_url is required for the docs"
         self.openapi_schema: Optional[Dict[str, Any]] = None
         self.setup()
 
-    def openapi(self) -> Dict:
+    def openapi(self, openapi_prefix: str = "") -> Dict:
         if not self.openapi_schema:
             self.openapi_schema = get_openapi(
                 title=self.title,
@@ -95,7 +102,7 @@ class FastAPI(Starlette):
                 openapi_version=self.openapi_version,
                 description=self.description,
                 routes=self.routes,
-                openapi_prefix=self.openapi_prefix,
+                openapi_prefix=openapi_prefix,
             )
         return self.openapi_schema
 
@@ -103,17 +110,22 @@ class FastAPI(Starlette):
         if self.openapi_url:
 
             async def openapi(req: Request) -> JSONResponse:
-                return JSONResponse(self.openapi())
+                root_path = req.scope.get("root_path", "").rstrip("/")
+                return JSONResponse(self.openapi(root_path))
 
             self.add_route(self.openapi_url, openapi, include_in_schema=False)
-            openapi_url = self.openapi_prefix + self.openapi_url
         if self.openapi_url and self.docs_url:
 
             async def swagger_ui_html(req: Request) -> HTMLResponse:
+                root_path = req.scope.get("root_path", "").rstrip("/")
+                openapi_url = root_path + self.openapi_url
+                oauth2_redirect_url = self.swagger_ui_oauth2_redirect_url
+                if oauth2_redirect_url:
+                    oauth2_redirect_url = root_path + oauth2_redirect_url
                 return get_swagger_ui_html(
                     openapi_url=openapi_url,
                     title=self.title + " - Swagger UI",
-                    oauth2_redirect_url=self.swagger_ui_oauth2_redirect_url,
+                    oauth2_redirect_url=oauth2_redirect_url,
                     init_oauth=self.swagger_ui_init_oauth,
                 )
 
@@ -132,6 +144,8 @@ class FastAPI(Starlette):
         if self.openapi_url and self.redoc_url:
 
             async def redoc_html(req: Request) -> HTMLResponse:
+                root_path = req.scope.get("root_path", "").rstrip("/")
+                openapi_url = root_path + self.openapi_url
                 return get_redoc_html(
                     openapi_url=openapi_url, title=self.title + " - ReDoc"
                 )
@@ -143,6 +157,8 @@ class FastAPI(Starlette):
         )
 
     async def __call__(self, scope: Scope, receive: Receive, send: Send) -> None:
+        if self.root_path:
+            scope["root_path"] = self.root_path
         if AsyncExitStack:
             async with AsyncExitStack() as stack:
                 scope["fastapi_astack"] = stack
