@@ -1128,7 +1128,7 @@ def test_get_path(path, expected_status, expected_response):
 
 def test_swagger_ui():
     response = client.get("/docs")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.headers["content-type"] == "text/html; charset=utf-8"
     assert "swagger-ui-dist" in response.text
     assert (
@@ -1139,13 +1139,13 @@ def test_swagger_ui():
 
 def test_swagger_ui_oauth2_redirect():
     response = client.get("/docs/oauth2-redirect")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.headers["content-type"] == "text/html; charset=utf-8"
     assert "window.opener.swaggerUIRedirectOauth2" in response.text
 
 
 def test_redoc():
     response = client.get("/redoc")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.headers["content-type"] == "text/html; charset=utf-8"
     assert "redoc@next" in response.text
