@@ -25,7 +25,7 @@ client = TestClient(app)
 def test_route_converters_int():
     # Test integer conversion
     response = client.get("/int/5")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"int": 5}
     assert app.url_path_for("int_convertor", param=5) == "/int/5"
 
@@ -33,7 +33,7 @@ def test_route_converters_int():
 def test_route_converters_float():
     # Test float conversion
     response = client.get("/float/25.5")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"float": 25.5}
     assert app.url_path_for("float_convertor", param=25.5) == "/float/25.5"
 
@@ -41,7 +41,7 @@ def test_route_converters_float():
 def test_route_converters_path():
     # Test path conversion
     response = client.get("/path/some/example")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"path": "some/example"}
 
 
