@@ -101,17 +101,17 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_path_operation():
     response = client.get("/items/foo")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"id": "foo", "value": "there goes my hero"}
 
 
 def test_path_operation_not_found():
     response = client.get("/items/bar")
-    assert response.status_code == 404
+    assert response.status_code == 404, response.text
     assert response.json() == {"message": "Item not found"}
