@@ -85,7 +85,7 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
@@ -176,5 +176,5 @@ def test_post_body(path, body, expected_status, expected_response):
 
 def test_post_broken_body():
     response = client.post("/items/", data={"name": "Foo", "price": 50.5})
-    assert response.status_code == 400
+    assert response.status_code == 400, response.text
     assert response.json() == {"detail": "There was an error parsing the body"}
