@@ -37,11 +37,11 @@ html_contents = """
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_get_custom_response():
     response = client.get("/items/")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.text == html_contents
