@@ -73,19 +73,19 @@ openapi_schema = {
 
 def test_openapi_schema():
     response = client.get("/openapi.json")
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == openapi_schema
 
 
 def test_multi_query_values():
     url = "/items/?q=foo&q=bar"
     response = client.get(url)
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"q": ["foo", "bar"]}
 
 
 def test_query_no_values():
     url = "/items/"
     response = client.get(url)
-    assert response.status_code == 200
+    assert response.status_code == 200, response.text
     assert response.json() == {"q": None}
